<?php

if ( ! function_exists( 'wordecho_setup' ) ):
function wordecho_setup() {
	add_theme_support( 'automatic-feed-links' );

	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'wordecho' ),
	) );

	add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery' ) );
}
endif;

if ( ! isset( $content_width ) ) $content_width = 640;

add_action( 'after_setup_theme', 'wordecho_setup' );

function wordecho_filter_wp_title( $title ) {
    global $page, $paged;
	$site_name = get_bloginfo( 'name' );
    $filtered_title = $site_name.' | ' . $title;
    if ( is_front_page() ) {
        $site_description = get_bloginfo( 'description' );
        $filtered_title .= $site_description;
		if ( $paged >= 2 || $page >= 2 )
		$filtered_title .= ' | ' . sprintf( __( 'Page %s', 'wordecho' ), max( $paged, $page ) );	
    }
    return $filtered_title;
}
add_filter( 'wp_title', 'wordecho_filter_wp_title' );


function wordecho_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'wordecho' ),
		'id' => 'sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );

}
add_action( 'init', 'wordecho_widgets_init' );

if ( ! function_exists( 'wordecho_content_nav' ) ):
function wordecho_content_nav( $nav_id ) {
	global $wp_query;

	?>
	<nav id="<?php echo $nav_id; ?>">

	<?php if ( is_single() ) : ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'wordecho' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'wordecho' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'wordecho' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'wordecho' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav>
	<?php
}
endif; 
function wordecho_excerpt_length( $length ) {
	return 260;
}
add_filter( 'excerpt_length', 'wordecho_excerpt_length' );
function wordecho_excerpt_more($more) {
	global $post;
	return '[.....] <a href="'. get_permalink($post->ID) . '" title="Continue reading" rel="nofollow">More?</a>';
}
add_filter('excerpt_more', 'wordecho_excerpt_more');

if ( ! function_exists( 'wordecho_comment' ) ) :
function wordecho_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'wordecho' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'wordecho' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer>
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 40 ); ?>
					<?php printf( __( '%s <span class="says">says:</span>', 'wordecho' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div>
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'Your comment is awaiting moderation.', 'wordecho' ); ?></em>
					<br />
				<?php endif; ?>

				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time pubdate datetime="<?php comment_time( 'c' ); ?>">
					<?php printf( __( '%1$s at %2$s', 'wordecho' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(Edit)', 'wordecho' ), ' ' );
					?>
				</div>
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div>
		</article>

	<?php
			break;
	endswitch;
}
endif; 
 
 

function wordecho_posted_on(  ) {
  
	printf( __( '<span class="sep"></span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a>', 'wordecho' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ) 
		
	);
 }